<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://dabex.eu
 * @since      1.0.0
 *
 * @package    Gls
 * @subpackage Gls/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Gls
 * @subpackage Gls/admin
 * @author     Dabex Agency <contact@dabex.eu>
 */
class Gls_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Gls_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Gls_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/gls-admin.css', array(), $this->version, 'all' );
		wp_enqueue_style( 'font-awesome', plugin_dir_url( __FILE__ ) .'css/font-awesome.min.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Gls_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Gls_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/gls-admin.js', array( 'jquery' ), $this->version, false );
		wp_enqueue_script( 'bootstrap', plugin_dir_url( __FILE__ ) . 'js/bootstrap.min.js', array( 'jquery' ), $this->version, false );

	}

	/**
	 * Register the administration menu for this plugin into the WordPress Dashboard menu.
	 *
	 * @since    1.0.0
	 */

	public function add_plugin_admin_menu() {

	    /*
	     * Add a settings page for this plugin to the Settings menu.
	     *
	     * NOTE:  Alternative menu locations are available via WordPress administration menu functions.
	     *
	     *        Administration Menus: http://codex.wordpress.org/Administration_Menus
	     *
	     */
	    add_options_page( 'GLS Shipping Settings', 'GLS', 'manage_options', $this->plugin_name, array($this, 'display_plugin_setup_page')
	                     );
	  }

	 /**
	 * Add settings action link to the plugins page.
	 *
	 * @since    1.0.0
	 */

	 public function add_action_links( $links ) {
	    /*
	    *  Documentation : https://codex.wordpress.org/Plugin_API/Filter_Reference/plugin_action_links_(plugin_file_name)
	    */
	    $settings_link = array(
	                           '<a href="' . admin_url( 'options-general.php?page=' . $this->plugin_name ) . '">' . __('Settings', $this->plugin_name) . '</a>',
	                           );
	    return array_merge(  $settings_link, $links );

	  }

	/**
	 * Render the settings page for this plugin.
	 *
	 * @since    1.0.0
	 */

	public function display_plugin_setup_page() {
		include_once( 'partials/gls-admin-display.php' );
	}

	/**
	 *  Validate and sanitaze form
	 */

	public function validate($input) {
    // All inputs
    $valid = array();

    //Cleanup
    $valid['username'] = sanitize_text_field($input['username']);
    $valid['password'] = sanitize_text_field($input['password']);
    $valid['senderid'] = sanitize_text_field($input['senderid']);
    $valid['alias'] = sanitize_text_field($input['alias']);
    $valid['sms_text'] = sanitize_text_field($input['sms_text']);
    $valid['sender_name'] = sanitize_text_field($input['sender_name']);
    $valid['sender_address'] = sanitize_text_field($input['sender_address']);
    $valid['sender_zipcode'] = sanitize_text_field($input['sender_zipcode']);
    $valid['sender_city'] = sanitize_text_field($input['sender_city']);
    $valid['sender_contact'] = sanitize_text_field($input['sender_contact']);
    $valid['sender_phone'] = sanitize_text_field($input['sender_phone']);
    $valid['sender_email'] = sanitize_text_field($input['sender_email']);

    //Get Old values
    if (isset($_POST['submitGLScont1'])) {
	    $old_option = get_option($this->plugin_name.'_cont_1'); // Your option name
    }
    if (isset($_POST['submitGLScont2'])) {
	    $old_option = get_option($this->plugin_name.'_cont_2'); // Your option name
    }
    if (isset($_POST['submitGLScont2'])) {
	    $old_option = get_option($this->plugin_name.'_cont_3'); // Your option name
		}

    if (empty($valid['username']) || empty($valid['password']) || empty($valid['senderid']) || empty($valid['sender_name']) || empty($valid['sender_address']) || empty($valid['sender_zipcode']) || empty($valid['sender_city'])) {
    	$valid = $old_option;
			add_settings_error(
				'requiredTextFieldEmpty',
				'empty',
				'Completeaza toate campurile necesare (cele cu *)',
				'error'
			);
		}

    return $valid;
 }


 public function options_update() {

 	if (isset($_POST['submitGLScont1'])) {
    register_setting($this->plugin_name, $this->plugin_name.'_cont_1', array($this, 'validate'));
 	}
 	if (isset($_POST['submitGLScont2'])) {
    register_setting($this->plugin_name, $this->plugin_name.'_cont_2', array($this, 'validate'));
  }
 	if (isset($_POST['submitGLScont3'])) {
    register_setting($this->plugin_name, $this->plugin_name.'_cont_3', array($this, 'validate'));
  }
 }

}
